/************************************************************************/
/*  Routines to read event list.					*/
/*									*/
/*	Douglas Neuhauser						*/
/*	Seismological Laboratory					*/
/*	University of California, Berkeley				*/
/*	doug@seismo.berkeley.edu					*/
/*									*/
/************************************************************************/

/*
 * Copyright (c) 1996-2000 The Regents of the University of California.
 * All Rights Reserved.
 * 
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for educational, research and non-profit purposes,
 * without fee, and without a written agreement is hereby granted,
 * provided that the above copyright notice, this paragraph and the
 * following three paragraphs appear in all copies.
 * 
 * Permission to incorporate this software into commercial products may
 * be obtained from the Office of Technology Licensing, 2150 Shattuck
 * Avenue, Suite 510, Berkeley, CA  94704.
 * 
 * IN NO EVENT SHALL THE UNIVERSITY OF CALIFORNIA BE LIABLE TO ANY PARTY
 * FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES,
 * INCLUDING LOST PROFITS, ARISING OUT OF THE USE OF THIS SOFTWARE AND
 * ITS DOCUMENTATION, EVEN IF THE UNIVERSITY OF CALIFORNIA HAS BEEN
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 * THE UNIVERSITY OF CALIFORNIA SPECIFICALLY DISCLAIMS ANY WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE SOFTWARE
 * PROVIDED HEREUNDER IS ON AN "AS IS" BASIS, AND THE UNIVERSITY OF
 * CALIFORNIA HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT,
 * UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
 */

#ifndef lint
static char sccsid[] = "$Id: get_events.c,v 1.6 2003/10/29 21:17:28 lombard Exp $ ";
#endif

#include <stdio.h>
#include <string.h>

#include "externals.h"

#define	LINELEN 255
#define	N	100

int get_events 
   (FILE	*fp,		/* input FILE.				*/
    EVENT	**p_evts)	/* ptr to ptr to events (returned).	*/
{
    EVENT *evt = NULL;
    EVENT *evtbuf = NULL;
    int evtbufnum = 0;
    int nevents = 0;
    char line[LINELEN+1];
    char date_str[40], time_str[40];
    INT_TIME *p_it;
    int error = 0;

    while (fgets(line,LINELEN,fp)) {
	/* Ensure sufficient space for this event. */
	if (nevents >= evtbufnum) {
	    if (evtbuf == NULL) {
		if ((evt = evtbuf = (EVENT *)malloc(N*sizeof(EVENT))) == NULL) {
		    fprintf (info, "Error mallocing event buffer\n");
		    exit(1);
		}
	    }
	    else {
		if ((evtbuf = (EVENT *)realloc (evtbuf,(evtbufnum+N)*sizeof(EVENT))) == NULL) {
		    fprintf (info, "Error mallocing event buffer\n");
		    exit(1);
		}
	    }
	    evtbufnum += N;
	}
	evt = evtbuf+nevents;
	/* Scan and save event.	*/
	if (sscanf(line,"%s",date_str)==1) {
	    if (strchr(date_str,',')) {
		/* Date string contains time.   */
		if (sscanf(line,"%*s %lf %lf %lf %lf", 
			   &evt->loc.lat, &evt->loc.lon, &evt->depth, 
			   &evt->mag) != 4) ++error;
	    }
	    else {
		/* Date string does not contain time.   */
		if (sscanf(line,"%*s %s %lf %lf %lf %lf", time_str,
			   &evt->loc.lat, &evt->loc.lon, &evt->depth, 
			   &evt->mag) != 5) ++error;
		strcat(date_str,",");
		strcat(date_str,time_str);
	    }
	}
	else ++error;
	if (error) {
	    fprintf(info, "Error reading event file: %s", line);
	    exit(1);
	}
	if ((p_it = parse_date(date_str)) == NULL) {
	    fprintf(info, "Error parsing date/time %s in event file\n", date_str);
	    *p_evts = NULL;
	    return(-1);
	}
	evt->time = *p_it;
	++nevents;
    }
    *p_evts = evtbuf;
    return(nevents);
}

