.\$Id: msextract.man,v 1.6 2004/03/16 00:11:45 doug Exp $ 
.TH msextract 1 "15 Mar 2004" BDSN
.SH NAME
msextract - extract MiniSEED data for events from a MiniSEED data file.
.SH SYNOPSIS
.B msextract
\fB\-e\ \fI event_file\fR
[\ \fB\-o\ \fI output_file\fR]
[\ \fB\-b\ \fI box_file\fR]
[\ \fB\-p\ \fI time_span\fR]
[\ \fB\-s\ \fI time_span\fR]
[\ \fB\-f\ \fI time_span\fR]
[\ \fB\-l\ \fI time_span\fR]
[\ \fB\-w\ \fI window_selection\fR]
[\ \fB\-d\ \fI debug_option\fR]
[\ \fB\-h\fR\ ]
[\ \fIinput_file\fR\ ]
.br
.SH DESCRIPTION
The program
.B msextract
extracts MiniSEED data records for the specified events from the input file,
and writes the extracted MiniSEED records to the output file.
It can be used to extract the "appropriate" time window for a specified event
based on phase arrival times (p and s) and/or event origin time.
In addition, a box (polygonal region) and time window can be
specified. Stations that lie within the box will have data saved for the time
window. 
The event time, requested time windows, and the status of data extraction for
that time window will be display for each event.
.SH OPTIONS
.TP
\fB\-e \fIevent_file\fR
.br
specifies the name of the file containing a list of events.  
The event file must be in on of the following formats:
.nf
.sp
date time latitude longitude depth magnitude
date,time latitude longitude depth magnitude
.sp
.fi
Any additional information on the event line is ignored.
.TP
\fB\-b \fIbox_file\fR
.br
specifies the name of a box file. This file may be empty, or it may contain,
on separate lines, start time, end time and latitude-longitude pairs. The
start and end times must be in format parsible by parse_date (qlib2) with no
space between date and time. The latitude longitude pairs describe a polygon,
thus there must be at least three of them. The first point should \fBnot be
repeated \fRat the end of the list. Data for stations that lie within the
polygon will have data extracted from the start time to the end time.
If the box file is empty, it will be silently ignored.
.nf
An example of this file is:

2003.290.14:10:10.1
2003.290.15:15:15.2
37.9  -121.8
38.0  -121.8
38.0  -122.0
37.9  -122.0
.ad
.TP
\fB\-o \fIoutput_file\fR
.br
specifies the name of the output file.  If no file is specified, output will
be written to stdout.
.TP
\fB\-p \fItime_span\fR
.br
specifies how much data should be extracted preceeding the P-wave arrival
time, and  may be specified in either seconds, minutes, or hours.
The time_span is an integer followed immediately by the character 
\fBS\fR, \fBM\fR, \fBH\fR, \fBd\fR, or \fBm\fR.  Note that time designators
are upper case.  If no character is specified, seconds are assumed.  
The default pre_event time_span is 30S.
.TP
\fB\-s \fItime_span\fR
.br
specifies how much data should be extracted following the slowest surface
wave arrival time, and may be specified in either seconds, minutes, or hours.
The time_span is an integer followed immediately by the character 
\fBS\fR, \fBM\fR, \fBH\fR, \fBd\fR, or \fBm\fR.  Note that time designators
are upper case.  If no character is specified, seconds are assumed.  The
default duration time_span is 60S.
.TP
\fB\-f \fItime_span\fR
.br
specifies how much data should be extracted for a fixed window relative to
the origin time.  This option specifies how much data should be extracted
preceeding the origin 
time, and  may be specified in either seconds, minutes, or hours.
The time_span is an integer followed immediately by the character 
\fBS\fR, \fBM\fR, \fBH\fR, \fBd\fR, or \fBm\fR.  Note that time designators
are upper case.  If no character is specified, seconds are assumed.  
The default pre_event time_span is 0S.
.TP
\fB\-l \fItime_span\fR
.br
specifies how the length of the fixed window relative to
the origin window.  This length is relative to the start time specified
by the \fB-f\fR option,
and  may be specified in either seconds, minutes, or hours.
The time_span is an integer followed immediately by the character 
\fBS\fR, \fBM\fR, \fBH\fR, \fBd\fR, or \fBm\fR.  Note that time designators
are upper case.  If no character is specified, seconds are assumed.  
The default pre_event time_span is 300S.
.TP
\fB\-w \fIwindow_criteria\fR
.br
specifes one or more characters that indicates which windowing criteria
should be used in selecting the final time window for data extraction.
The string \fBp\fR specifies that only the window specified by the phase
arrivals should be used.
The string \fBf\fR specifies that only the window specified by the fixed
time window relative to the origin time should be used.
The string \fBpf\fR specifies that both the phase and origin time windows
should be used.  The program will use the min(start_times) and the
max(end_times) for the extraction window.
The default window_criteria is \fBpf\fR.
.TP
\fB\-d \fIn\fR
.br
specifies a debug option.  
.nf
.sp
1 = debug time window.
2 = debug save data records.
4 = debug discarded data records.
.sp
.fi
The debug option will output diagnostic
information about the event distance and expected P and surface wave arrival
times with respect to the station and event time.
The debug values may be added together to debug multiple items.
.TP
.B \-h
print out a simple help message with syntax and explaination of the options.
.TP
\fIinput_file\fR
.br
specifies the input file to be read.  If no file is specified, 
data is read from stdin.
.SH EXAMPLES
.nf
1. Extract data for events selected from a catalog.
eqselect -cat -t 940101233000 940300000000 -m 2.0 9.0 | catlist > eq.list
msextract -e eq.list -o PKD1.HHZ.subset PKD1.BK.HHZ.D.1994.092.0000

2.  Ensure that we have a fixed time window base on the origin time as 
well as all p and s arrivals.
msextract -e eq.list -w pf -p 30 -s 60 -f 30S -l 360S -o PKD1.BHZ.subset PKD1.BK.BHZ.D.1994.092.0000

.SH FILES
.TP
/usr/contrib/data/bdsn/stat.db.coord
.br
Station coordinate file.  The file must contains lines consising of
whitespace delimited tokens containing at least the following information.
.nf

station	latitude longitude depth start_time end_time

An example of this file is:

BDM    37.953970 -121.865540  219.8 1998.316.0000 3000.001.0000
BKS    37.876220 -122.235580  243.9 1987.125.0000 3000.001.0000
BRIB   37.918860 -122.151790  219.7 1995.174.1600 3000.001.0000


.ad
The lines may contains additional information which will be ignored.

.SH BUGS
Only MiniSEED data files can be read by msextract.
.SH AUTHOR
Doug Neuhauser, Berkeley Seismological Laboratory, doug@seismo.berkeley.edu
